searchData={"items":[{"type":"module","title":"OptimumCredo","doc":"Documentation for `OptimumCredo`.","ref":"OptimumCredo.html"},{"type":"module","title":"OptimumCredo.Check.Readability.DepsOrder","doc":"","ref":"OptimumCredo.Check.Readability.DepsOrder.html"},{"type":"module","title":"Basics - OptimumCredo.Check.Readability.DepsOrder","doc":"> #### This check is disabled by default. {: .neutral}\n>\n> [Learn how to enable it](config_file.html#checks) via `.credo.exs`.\n\n\n\nThis check has a base priority of `low` and works with any version of Elixir.","ref":"OptimumCredo.Check.Readability.DepsOrder.html#module-basics"},{"type":"module","title":"Explanation - OptimumCredo.Check.Readability.DepsOrder","doc":"Alphabetically ordered dependencies are more easily scannable by the reader.\n\n    # preferred\n\n    defp app_deps do\n      [\n        {:bcrypt_elixir, \"~> 3.0\"},\n        {:mdex, \"~> 0.4.0\"},\n        {:multipart, \"~> 0.4\"},\n        {:number, \"~> 1.0\"},\n        {:plug, \"~> 1.14\"}\n      ]\n    end\n\n    # NOT preferred\n\n    defp app_deps do\n      [\n        {:bcrypt_elixir, \"~> 3.0\"},\n        {:multipart, \"~> 0.4\"},\n        {:number, \"~> 1.0\"},\n        {:plug, \"~> 1.14\"},\n        {:mdex, \"~> 0.4.0\"}\n      ]\n    end\n\nDependencies should be alphabetically ordered within each deps group:\n- app_deps\n- optimum_deps\n\nLike all `Readability` issues, this one is not a technical concern.\nBut you can improve the odds of others reading and liking your code by making\nit easier to follow.","ref":"OptimumCredo.Check.Readability.DepsOrder.html#module-explanation"},{"type":"module","title":"Check-Specific Parameters - OptimumCredo.Check.Readability.DepsOrder","doc":"Use the following parameters to configure this check:\n\n### `:sort_method`\n\n  The ordering method to use.\n  \n  Options\n  - `:alpha` - Alphabetical case-insensitive sorting.\n  \n\n*This parameter defaults to* `:alpha`.","ref":"OptimumCredo.Check.Readability.DepsOrder.html#module-check-specific-parameters"},{"type":"module","title":"General Parameters - OptimumCredo.Check.Readability.DepsOrder","doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"OptimumCredo.Check.Readability.DepsOrder.html#module-general-parameters"},{"type":"module","title":"OptimumCredo.Check.Readability.ImportOrder","doc":"","ref":"OptimumCredo.Check.Readability.ImportOrder.html"},{"type":"module","title":"Basics - OptimumCredo.Check.Readability.ImportOrder","doc":"> #### This check is disabled by default. {: .neutral}\n>\n> [Learn how to enable it](config_file.html#checks) via `.credo.exs`.\n\n\n\nThis check has a base priority of `low` and works with any version of Elixir.","ref":"OptimumCredo.Check.Readability.ImportOrder.html#module-basics"},{"type":"module","title":"Explanation - OptimumCredo.Check.Readability.ImportOrder","doc":"Alphabetically ordered imports are more easily scannable by the reader.\n\n    # preferred\n\n    import ModuleA\n    import ModuleB\n    import ModuleC\n\n    # NOT preferred\n\n    import ModuleA\n    import ModuleC\n    import ModuleB\n\nImports should be alphabetically ordered among their group:\n\n    # preferred\n\n    import ModuleC\n    import ModuleD\n\n    import ModuleA\n    import ModuleB\n\n    # NOT preferred\n\n    import ModuleC\n    import ModuleD\n\n    import ModuleB\n    import ModuleA\n\nLike all `Readability` issues, this one is not a technical concern.\nBut you can improve the odds of others reading and liking your code by making\nit easier to follow.","ref":"OptimumCredo.Check.Readability.ImportOrder.html#module-explanation"},{"type":"module","title":"Check-Specific Parameters - OptimumCredo.Check.Readability.ImportOrder","doc":"Use the following parameters to configure this check:\n\n### `:sort_method`\n\n  The ordering method to use.\n  \n  Options\n  - `:alpha` - Alphabetical case-insensitive sorting.\n  - `:ascii` - Case-sensitive sorting where upper case characters are ordered\n                before their lower case equivalent.\n  \n\n*This parameter defaults to* `:alpha`.","ref":"OptimumCredo.Check.Readability.ImportOrder.html#module-check-specific-parameters"},{"type":"module","title":"General Parameters - OptimumCredo.Check.Readability.ImportOrder","doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"OptimumCredo.Check.Readability.ImportOrder.html#module-general-parameters"},{"type":"module","title":"OptimumCredo.Check.Readability.TypespecOrder","doc":"","ref":"OptimumCredo.Check.Readability.TypespecOrder.html"},{"type":"module","title":"Basics - OptimumCredo.Check.Readability.TypespecOrder","doc":"> #### This check is disabled by default. {: .neutral}\n>\n> [Learn how to enable it](config_file.html#checks) via `.credo.exs`.\n\n\n\nThis check has a base priority of `low` and works with any version of Elixir.","ref":"OptimumCredo.Check.Readability.TypespecOrder.html#module-basics"},{"type":"module","title":"Explanation - OptimumCredo.Check.Readability.TypespecOrder","doc":"Alphabetically ordered typespecs are more easily scannable by the reader.\n\n    # preferred\n\n    @type apple :: String.t()\n    @type banana :: String.t()\n    @type cherry :: String.t()\n\n    # NOT preferred\n\n    @type apple :: String.t()\n    @type cherry :: String.t()\n    @type banana :: String.t()\n\nTypespecs should be alphabetically ordered among their group:\n\n    # preferred\n\n    @type apple :: String.t()\n    @type banana :: String.t()\n\n    @typep color :: String.t()\n    @typep dimension :: integer()\n\n    # NOT preferred\n\n    @type banana :: String.t()\n    @type apple :: String.t()\n\n    @typep dimension :: integer()\n    @typep color :: String.t()\n\nLike all `Readability` issues, this one is not a technical concern.\nBut you can improve the odds of others reading and liking your code by making\nit easier to follow.","ref":"OptimumCredo.Check.Readability.TypespecOrder.html#module-explanation"},{"type":"module","title":"Check-Specific Parameters - OptimumCredo.Check.Readability.TypespecOrder","doc":"Use the following parameters to configure this check:\n\n### `:sort_method`\n\n  The ordering method to use.\n  \n  Options\n  - `:alpha` - Alphabetical case-insensitive sorting.\n  - `:ascii` - Case-sensitive sorting where upper case characters are ordered\n                before their lower case equivalent.\n  \n\n*This parameter defaults to* `:alpha`.","ref":"OptimumCredo.Check.Readability.TypespecOrder.html#module-check-specific-parameters"},{"type":"module","title":"General Parameters - OptimumCredo.Check.Readability.TypespecOrder","doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"OptimumCredo.Check.Readability.TypespecOrder.html#module-general-parameters"},{"type":"extras","title":"optimum_credo","doc":"# optimum_credo","ref":"readme.html"},{"type":"extras","title":"Installation - optimum_credo","doc":"Add the `:optimum_credo` package to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:optimum_credo, \"~> 0.1\", only: :test, runtime: false},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - optimum_credo","doc":"Add the checks you want in your `.credo.exs` configuration file.\n\nFor example:\n\n```elixir\n{OptimumCredo.Check.Readability.ImportOrder, []},\n```\n\nThen you can run `mix credo` per usual.","ref":"readme.html#usage"},{"type":"extras","title":"Available rules - optimum_credo","doc":"```elixir\nOptimumCredo.Check.Readability.DepsOrder\nOptimumCredo.Check.Readability.ImportOrder\nOptimumCredo.Check.Readability.TypespecOrder\n```","ref":"readme.html#available-rules"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}